@@ -165,12 +165,16 @@ sub add_standard_shopping_campaign {
       # the ads from immediately serving. Set to ENABLED once you've added
       # targeting and the ads are ready to serve.
       status => Google::Ads::GoogleAds::V15::Enums::CampaignStatusEnum::PAUSED,
-      # Set the bidding strategy to Manual CPC (with eCPC enabled).
+      # Set the bidding strategy to Manual CPC (with eCPC disabled). eCPC for
+      # standard Shopping campaigns is deprecated. If eCPC is set to true,
+      # Google Ads ignores the setting and behaves as if the setting was false.
+      # See this blog post for more information:
+      # https://ads-developers.googleblog.com/2023/09/google-ads-shopping-campaign-enhanced.html
       # Recommendation: Use one of the automated bidding strategies for shopping
       # campaigns to help you optimize your advertising spend. More information
       # can be found here: https://support.google.com/google-ads/answer/6309029.
       manualCpc => Google::Ads::GoogleAds::V15::Common::ManualCpc->new(
-        {enhancedCpcEnabled => "true"}
+        {enhancedCpcEnabled => "false"}
       ),
       # Set the budget.
       campaignBudget => $budget_resource_name
